﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Threading;
using HeuristicLab.Clients.Hive;
using HeuristicLab.Core;


namespace HiveDrain {
  /// <summary>
  /// Retrieves all jobs and starts downloading their tasks
  /// </summary>
  class JobDownloader {
    public string RootLocation { get; set; }

    public string NamePattern { get; set; }

    private ILog log;

    public JobDownloader(string location, string pattern, ILog log) {
      RootLocation = location;
      NamePattern = pattern;
      this.log = log;
    }

    public void Start() {
      var jobsLoaded = HiveServiceLocator.Instance.CallHiveService<IEnumerable<Job>>(s => s.GetJobs());
      Semaphore limitSemaphore = new Semaphore(HeuristicLabHiveDrainApplication.MaxParallelDownloads, HeuristicLabHiveDrainApplication.MaxParallelDownloads);

      foreach (Job j in jobsLoaded) {
        if ((!String.IsNullOrEmpty(NamePattern) && j.Name.Contains(NamePattern)) ||
            String.IsNullOrEmpty(NamePattern)) {
          string jobPath = Path.Combine(RootLocation, String.Format("{0} - {1}", j.Name, j.Id));
          log.LogMessage(String.Format("\"{0}\": {1}", j.Name, j.Id));

          JobTaskDownloader taskDownloader = new JobTaskDownloader(jobPath, j, limitSemaphore, log);
          taskDownloader.Start();
        } else {
          log.LogMessage(String.Format("\"{0}\": {1} ---> ignored", j.Name, j.Id));
        }
      }
    }
  }
}
